Struct security_framework::secure_transport::ClientBuilder [] [src]

pub struct ClientBuilder { /* fields omitted */ }

A builder type to simplify the creation of client side SslStreams.

Methods

impl ClientBuilder
[src]

Creates a new builder with default options.

Specifies the set of additional root certificates to trust when verifying the server's certificate.

Use the specified identity as a SSL/TLS client certificate.

Configure the minimum protocol that this client will support.

Requires the OSX_10_8 (or greater) feature.

Configure the minimum protocol that this client will support.

Requires the OSX_10_8 (or greater) feature.

Initiates a new SSL/TLS session over a stream connected to the specified domain.

Note that this method assumes that the stream S is in blocking mode, and it will return an error if the stream is set to nonblocking mode. If the stream S is in asynchronous operation (or may be) then you may use handshake2 instead.

Note that this method will likely be removed in the next major release in favor of handshake2.

Initiates a new SSL/TLS session over a stream connected to the specified domain.